#
# spec file for package libplist
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libplist
Version:        2.0.0
Release:        1.31
Summary:        Library for handling Apple Binary and XML Property Lists
License:        GPL-2.0 and LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            https://cgit.libimobiledevice.org/libplist.git
Source:         http://www.libimobiledevice.org/downloads/%{name}-%{version}.tar.bz2
Source99:       baselibs.conf
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python-cython
BuildRequires:  python-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libplist is a library for handling Apple Binary and XML Property Lists.

%package -n libplist3
Summary:        Library for handling Apple Binary and XML Property Lists
Group:          System/Libraries
Provides:       libplist = %{version}
Obsoletes:      libplist < %{version}

%description -n libplist3
libplist is a library for handling Apple Binary and XML Property Lists.

%package -n libplist++3
Summary:        Library for handling Apple Binary and XML Property Lists
Group:          System/Libraries
Provides:       libplist++ = %{version}
Obsoletes:      libplist++ < %{version}

%description -n libplist++3
libplist is a library for handling Apple Binary and XML Property Lists.

%package -n plistutil
Summary:        Library for handling Apple Binary and XML Property Lists
Group:          Hardware/Other
Requires:       libplist = %{version}
Provides:       plutil = %{version}
Obsoletes:      plutil < %{version}

%description -n plistutil
libplist is a library for handling Apple Binary and XML Property Lists.

This package contains an utility to convert PList files from binary to XML and
from XML to binary.

%package devel
Summary:        Library for handling Apple Binary and XML Property Lists -- Development Files
Group:          Development/Libraries/C and C++
Requires:       libplist = %{version}

%description devel
libplist is a library for handling Apple Binary and XML Property Lists.

This package contains the development files for C.

%package -n libplist++-devel
Summary:        Library for handling Apple Binary and XML Property Lists -- Development Files
Group:          Development/Libraries/C and C++
Requires:       libplist++ = %{version}
Requires:       libplist-devel

%description -n libplist++-devel
libplist is a library for handling Apple Binary and XML Property Lists.

This package contains the development files for C++.

%package -n python-plist
Summary:        Library for handling Apple Binary and XML Property Lists -- Python Bindings
Group:          Development/Languages/Python
Requires:       libplist3 = %{version}
Requires:       python-cython >= 0.13

%description -n python-plist
libplist is a library for handling Apple Binary and XML Property Lists.

This package contains the python bindings.

%prep
%setup -q
%build
%configure --disable-static
make %{?_smp_mflags}

%check
TZ=Europe/Vienna make check VERBOSE=1

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{python_sitearch}/*.la

# needed by python-imobiledevice build
mkdir -p %{buildroot}%{_includedir}/plist/cython
install -m 0644 cython/plist.pxd %{buildroot}%{_includedir}/plist/cython/plist.pxd

%if 0%{?_crossbuild}
cp -a %{buildroot}%{?_sysroot}/* %{buildroot}/
rm -fr %{buildroot}%{?_sysroot}
%endif

%post -n libplist3 -p /sbin/ldconfig
%postun -n libplist3 -p /sbin/ldconfig
%post -n libplist++3 -p /sbin/ldconfig
%postun -n libplist++3 -p /sbin/ldconfig

%files -n libplist3
%defattr(-,root,root)
%doc AUTHORS COPYING COPYING.LESSER README NEWS
%{_libdir}/libplist.so.*

%files -n libplist++3
%defattr(-,root,root)
%doc AUTHORS COPYING COPYING.LESSER README NEWS
%{_libdir}/libplist++.so.*

%files -n plistutil
%defattr(-,root,root)
%{_bindir}/plistutil

%files devel
%defattr(-,root,root,-)
%dir %{_includedir}/plist
%{_includedir}/plist/plist.h
%{_libdir}/libplist.so
%{_libdir}/pkgconfig/libplist.pc

%files -n libplist++-devel
%defattr(-,root,root,-)
%dir %{_includedir}/plist
%{_includedir}/plist/plist++.h
%{_includedir}/plist/Array.h
%{_includedir}/plist/Boolean.h
%{_includedir}/plist/Data.h
%{_includedir}/plist/Date.h
%{_includedir}/plist/Dictionary.h
%{_includedir}/plist/Integer.h
%{_includedir}/plist/Key.h
%{_includedir}/plist/Uid.h
%{_includedir}/plist/Node.h
%{_includedir}/plist/Real.h
%{_includedir}/plist/String.h
%{_includedir}/plist/Structure.h
%{_libdir}/libplist++.so
%{_libdir}/pkgconfig/libplist++.pc

%files -n python-plist
%defattr(-,root,root,-)
%dir %{_includedir}/plist/cython
%{_includedir}/plist/cython/plist.pxd
%{python_sitearch}/plist.so

%changelog
* Mon May  1 2017 mgorse@suse.com
- update to version 2.0.0:
  * Improved malformed XML and binary plist detection and error
    handling
  * Add parser debug/error output (when compiled with
  - -enable-debug), controlled via environment variables
  * Fix unicode character handling
  * Add PLIST_IS_* helper macros for the different node types
  * Extend date/time range and date conversion issues
  * Plug several memory leaks
  * Speed improvements for handling large plist files
  * Includes security fixes for:
  * CVE-2017-6440, CVE-2017-6439, CVE-2017-6438, CVE-2017-6437,
  * CVE-2017-6436, CVE-2017-6435, CVE-2017-5836, CVE-2017-5835,
  * CVE-2017-5834, * CVE-2017-5545, * CVE-2017-7982 (boo#1035312)
  ... and several others that didn't receive any CVE (yet).
* Thu Feb  2 2017 jengelh@inai.de
- RPM group assignment fixes
* Wed Jan 25 2017 i@marguerite.su
- update version 1.12+git20170119.6a44dfb
  * xplist: Fix limiited but possible XXE security vulnerability
    with XML
  * plistutil: use static buffer for stat()
  * plistutil: Plug some memory leaks
  * bplist: Fix possible crash in plist_from_bin() caused by access
    to already freed memory
  * bplist: Plug memory leaks caused by unused and unfreed buffer
  * bplist: Refactor binary plist parsing in a recursive way
  * xplist: Get rid of setlocale() and use custom function to print
    floating point values
  * Node.cpp: let plist_t operations free _node when in a container
  * cython: Fix module build with libplist already installed
  * bplist: Speed up plist_to_bin conversion for large plists
  * Implemented plist_is_binary() and plist_from_memory()
  * plist_data_compare: Make sure to compare the node sizes for integer
    nodes
  * xplist: Plug memory leak when converting PLIST_UID nodes to XML
  * Change internal storage of PLIST_DATE values from struct timeval
    to double
  * Use time64 implementation by Michael G Schwern to extend allowed
    date/time range
  * remove libxml2 in favor of custom XML parsing
  * base64: Rework base64decode to handle split encoded data correctly
  * plistutil: Prevent OOB heap buffer read by checking input size
  * plistutil: Use plist_is_binary() to check for binary plist data
  * bplist: Improve UINT_TO_HOST macro, remove uint24_from_be function
  * bplist: Check for invalid offset_size in bplist trailer
  * bplist: Use proper struct for binary plist trailer
  * bplist: Check for invalid ref_size in bplist trailer
- fixed CVE-2017-5209, boo#1019531
  * The base64decode function in base64.c allows attackers to
    obtaiin sensitive info from process memory or cause a denial
    of service (buffer over-read) via split encoded Apple Property
    List data.
* Tue Oct 21 2014 m.szulecki@libimobiledevice.org
- Enable %%check as it is provided by libplist and improves quality
* Fri Oct 17 2014 m.szulecki@libimobiledevice.org
- Update to version 1.12
  * Fix plist_from_bin() changing value nodes to key nodes in dictionaries
  * Avoid exporting non-public symbols
  * Prevent crash in plist_from_bin() when parsing unusual binary plists
  * Fix crash in String|Key::GetValue() and actually make C++ interface work
  * Fix memory leaks in new_xml_plist() and parse_real_node()
  * Fix header guards to conform to C++ standard
  * Update Cython based Python bindings and remove plist_new_key()
  * Fix key nodes not being output correctly if they contained XML entities
  * Fix handling and storage of signed vs. unsigned integer values
  * Fix date handling to respect the "Mac Epoch" instead of "Unix Epoch"
  * Remove plist_set_type() as it should not be used
  * Fix deprecated macros to work with older LLVM/Clang
  * Fix various shadowed declarations
  * Add documentation to explicitly describe memory buffer ownership
  * Fix memory leak in plist_from_bin()
  * Add various test cases based on fixes
  * Fix wrong timezone related date/time conversion of date nodes
  * Fix endian detection on MIPS architecture
  * Fix parallel build for autotools
* Mon Jun 16 2014 i@marguerite.su
- update version 1.11
  * Deprecated plist_dict_insert_item() in favor of plist_dict_set_item()
  * Updated cython bindings for Python 3.x
  * Removed swig python bindings
  * Changed build system to autotools
  * Added new plist_dict_merge() function
  * WIN32 (MinGW) + OSX compilation fixes
  * Made base64 decoding thread safe
- remove patch: libplist-1.8-pkgconfig.patch
  * upstream fixed
- added plist.pxd, needed by python-imobiledevice build
* Mon Apr 15 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Tue Aug 28 2012 cfarrell@suse.com
- license update: LGPL-2.1+
  LGPL-2.1 can be relicensed to GPL without further permission. No need to
  explicitly call out the GPL as a license option. Fedora has been using
  LGPL-2.1+ for awhile so gain compatibility there too
* Mon Apr  9 2012 opensuse@sukimashita.com
- Allow compilation on 11.4 by disabling cython bindings
* Mon Apr  2 2012 opensuse@sukimashita.com
- Update to version 1.8
  * Add Cython based Python bindings
  * Fix memory corruption in libcnary
  * Fix building on Big Endian systems
  * Removed glib dependency, libplist now uses bundled libcnary
  * Fix building of Python bindings with GCC 4.6
- Do not build SWIG bindings for Python
- Remove gcc46_build_fix.patch due to upstream fixes
- Update pkgconfig patch
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: set cmake root, python paths
- cross-build workaround: move installed files from sysroot to
  real root
* Tue Jun 28 2011 aj@suse.de
- Add baselibs.conf - needed by usbmuxd's baselibs.conf.
* Mon May 16 2011 cgiboudeaux@gmx.com
- Add gcc46_build_fix.patch. Fixes build with GCC4.6
* Sun Mar 20 2011 opensuse@sukimashita.com
- Update to version 1.4
  * New maintainer and source location
  * Update AUTHORS from git history
  * Fix Unicode writing in binary plists
  * Update plist doctype
  * Fix Dictionary copy constructor
  * Fix Mac OS X library install path detection
  * Plug memory leak when writing Unicode data
- Remove pkgconfig patch due to upstream fixes
* Wed Dec  8 2010 cristian.rodriguez@opensuse.org
- Fix both -devel package dependencies and broken pkgconfig file
* Tue Apr 27 2010 opensuse@sukimashita.com
- Update to version 1.3
  * Endianness, alignment and type-punning fixes
  * Fix armel floating point endianess
  * Allow compiling with mingw on Windows
  * Minor bugfixes
* Wed Mar 31 2010 vuntz@opensuse.org
- Clean up packaging, based on what I did in multimedia:libs.
* Thu Mar 25 2010 meissner@suse.de
- run prepare_spec
* Thu Jan 21 2010 opensuse@sukimashita.com
- Update to version 1.2
  * Fix xml entity conversion
  * Silence build warnings
- Remove upstreamed patches
* Sat Jan  9 2010 opensuse@sukimashita.com
- Add patches to fix xml entity conversion and tests
* Wed Dec 30 2009 opensuse@sukimashita.com
- Update to version 1.1
  * Fix use of integer nodes within Python Bindings
* Mon Dec  7 2009 opensuse@sukimashita.com
- Update to version 1.0
  * Bugfixes
  * Remove deprecated API
* Wed Oct 28 2009 opensuse@sukimashita.com
- Update to version 0.16
  * Build fixes
  * Fix issues with SWIG
* Sat Oct 24 2009 opensuse@sukimashita.com
- Update to version 0.15
  * Build fixes
- Update to version 0.14
  * Add C++ binding
  * Refactor API
  * Bugfixes
* Sat Jul 18 2009 opensuse@sukimashita.com
- Update to version 0.13
  * Add plist_copy for deep node copies
  * Add node setter functions
  * Unlink nodes from parent if free'd
  * Update Python bindings
* Tue May  5 2009 opensuse@sukimashita.com
- Update to version 0.12
  * Merge ascii and unicode handling in PLIST_STRING using UTF-8
  * Remove unicode related declaration in API (breaks API&ABI)
  * Fix bad variable type for date elements
  * Silence compiler warnings
  * Plugged few memory leaks
* Tue Apr 21 2009 opensuse@sukimashita.com
- Update to version 0.11
  * Fix Python binding segfaults
  * Python API additions
  * Better binary buffer handling in Python bindings
* Sun Apr 12 2009 opensuse@sukimashita.com
- Update to version 0.10
* Tue Apr  7 2009 opensuse@sukimashita.com
- Add patch to fix uninitialized buffer
* Sat Apr  4 2009 opensuse@sukimashita.com
- Initial package created
